@@ -327,6 +327,7 @@ class DataFrame:
             '%Y-%m-%d %H-%M-%S', (time.localtime(LMStopTime)))  # type(stop_time_ = str
         runtime = lmf_stop_time_int - lmf_start_time_int
 
+        print("%s" % self.file)
         print("Start:           %s" % start_time)
         print("Stop:            %s" % stop_time)
         print("Runtime [s]:     %d" % runtime)
@@ -579,7 +580,7 @@ class DataFrame:
         save_string = '%s_UNCLUSTERED,tof_cut=%s,ion_cut=%s,' \
                       'rad_cut=%s,time_cut=%s.jpeg' % \
                       (self.file[0:-4], self.tof_cut, self.ion_cut,
-                       self.rad_cut, self.time_cut),
+                       self.rad_cut, self.time_cut)
 
         return plot, save_string
 
